<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:ns="http://www.bourse.lu/rap/O41"
	xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
	xmlns:xs="http://www.w3.org/2001/XMLSchema"
	xmlns:ext="java:lu.bourse.api.deposant.action.xsl.XslManager"
	xmlns:fnbcl="http://www.bcl.lu/2006/bcl-xpath-functions"
	xmlns:saxon="http://saxon.sf.net/"
	extension-element-prefixes="saxon"
	version="2.0">

	<xsl:import href="../EDIFACT/EDIFACT.xsl"/>
	
	<xsl:param name="formatDateCd" />
	<xsl:output method="text" />
	
	<!-- 
		Fonction de conversion des numeros de lignes.
	-->
	<xsl:function name="fnbcl:convert-numLigne" as="xs:string">
		<!--  La chaine de caracteres a convertir. -->
		<xsl:param name="numLigne" as="xs:string" />
		<!--  a chaque numero de ligne ajouter un 0 sauf pour 
				•	1112 devient 11111
				•	1113 devient 11112
				•	1114 devient 11120
				•	1115 devient 11130
		-->
		<xsl:choose>
			<xsl:when test="$numLigne eq '1112'">
					<xsl:value-of select="'11111'" />
			</xsl:when>
			<xsl:when test="$numLigne eq '1113'">
					<xsl:value-of select="'11112'" />
			</xsl:when>
			<xsl:when test="$numLigne eq '1114'">
					<xsl:value-of select="'11120'" />
			</xsl:when>
			<xsl:when test="$numLigne eq '1115'">
					<xsl:value-of select="'11130'" />
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="concat($numLigne, '0')" />
			</xsl:otherwise>
		</xsl:choose>
	</xsl:function>

	<xsl:variable name="compteurCPT" select="0" as="xs:integer" saxon:assignable="yes"/>
	<xsl:variable name="compteurSegments" select="$NB_SEGMENTS_FIXES" as="xs:integer" saxon:assignable="yes"/>

	<xsl:template match="/ns:MsgInO41">
	
		<xsl:call-template name="HEADER-SECTION"/>
		<xsl:call-template name="SEGMENT-GROUP-1"/>
		<xsl:call-template name="SEGMENT-GROUP-3"/>
		<xsl:call-template name="SEGMENT-GROUP-4"/>
		<xsl:call-template name="VENTILATION-PORTEFEUILLE-TITRES-AVOIRS"/>
		<xsl:call-template name="SUMMARY-SECTION">
			<xsl:with-param name="compteur" select="$compteurCPT"/>
		</xsl:call-template>
		<xsl:call-template name="SEGMENT-GROUP-5"/>
	</xsl:template>
	
	<xsl:template name="HEADER-SECTION">
		<xsl:variable name="root" select="ns:other/ns:EltTech"/>
		<xsl:variable name="idAc" select="$root/ns:CdIdentAcCssf"/>
		<xsl:variable name="idAc7digit" select="ext:convertIdAcTo7Digit($idAc)"/>	
		<xsl:call-template name="EDIFACT-UNA"/>
		<xsl:call-template name="EDIFACT-UNB">
			<xsl:with-param name="cdIdentAc" select="$idAc7digit" />
			<xsl:with-param name="dtCre" select="$root/ns:DtCre" as="xs:dateTime" />
			<xsl:with-param name="motPasAc" select="$root/ns:MotPasAc" />
			<xsl:with-param name="formatDateCd" select="$formatDateCd" />
		</xsl:call-template>
		<xsl:call-template name="EDIFACT-UNH">
			<xsl:with-param name="cdIdentAc" select="$idAc7digit" />
			<xsl:with-param name="dtCre" select="$root/ns:DtCre" as="xs:dateTime"/>
			<xsl:with-param name="numMess" select="$root/ns:NumMess" />
			<xsl:with-param name="formatDateCd" select="$formatDateCd" />
		</xsl:call-template>
		<xsl:call-template name="EDIFACT-BGM">
			<xsl:with-param name="typeRapport" select="'TABLE-O-4.1--D-L-00001'"/>
		</xsl:call-template>
		<xsl:comment>Preparation Date...</xsl:comment>
		<xsl:call-template name="EDIFACT-DTM">
			<xsl:with-param name="typeDate" select="'242'" />
			<xsl:with-param name="date" select="$root/ns:DtCre" as="xs:dateTime"/>
			<xsl:with-param name="formatDateCd" select="$formatDateCd" />
		</xsl:call-template>
		<xsl:comment>...Preparation Date</xsl:comment>
		<xsl:comment>Transmission Date...</xsl:comment>
		<xsl:call-template name="EDIFACT-DTM">
			<xsl:with-param name="typeDate" select="'243'" />
			<xsl:with-param name="date" select="$root/ns:DtEnvoi" as="xs:dateTime"/>
			<xsl:with-param name="formatDateCd" select="$formatDateCd" />
		</xsl:call-template>
		<xsl:comment>...Transmission Date</xsl:comment>
		<xsl:variable name="root" select="ns:SeqInO41/ns:Conc1/ns:Context/ns:CollCompartRapO41"/>
		<xsl:call-template name="EDIFACT-PEI">
			<xsl:with-param name="periode" select="'Y'"/>
			<xsl:with-param name="dtDebRap" select="$root/ns:DtDebRap" as="xs:date"/>
			<xsl:with-param name="dtFinRap" select="$root/ns:DtFinRap" as="xs:date"/>
			<xsl:with-param name="formatDateCd" select="$formatDateCd" />
		</xsl:call-template>
		<xsl:variable name="root" select="ns:SeqInO41/ns:Conc1/ns:Context/ns:StructJurOpc"/>
		<xsl:variable name="cdStructJurOpcTemp" select="$root/ns:CdStructJurOpc"/>
		<xsl:call-template name="EDIFACT-SJS">
			<xsl:with-param name="cdStructJurOpc" select="ext:mapping('CD_STRUCT_JUR_OPC_BDL', $cdStructJurOpcTemp)"/> 
			<xsl:with-param name="codifInstrFonds" select="$root/../ns:CollCompartRapO41/ns:CdCssfOpc"/>
			<xsl:with-param name="codifInstrCompart" select="$root/../ns:CollCompartRapO41/ns:CdCssfCompart"/>
		</xsl:call-template>
	</xsl:template>
	
	<xsl:template name="SEGMENT-GROUP-1">
		<xsl:variable name="root" select="ns:SeqInO41/ns:Conc1/ns:Context/ns:InstrFonds"/>
		<xsl:call-template name="EDIFACT-NAD">
			<xsl:with-param name="libAbrInstr" select="$root/ns:LibAbrInstr"/>
			<xsl:with-param name="adr" select="$root/../ns:Tech/ns:Adr"/>
			<xsl:with-param name="ville" select="$root/../ns:Tech/ns:Ville"/>
			<xsl:with-param name="cdPostal" select="$root/../ns:Tech/ns:CdPostal"/>
			<xsl:with-param name="pays" select="ext:mapping('IDENTIFIANT_PAYS', $root/../ns:Tech/ns:Pays)"/>
		</xsl:call-template>
		<xsl:variable name="root" select="ns:SeqInO41/ns:Conc1/ns:Context/ns:TechContact"/>
		<xsl:call-template name="EDIFACT-CTA">
			<xsl:with-param name="titre" select="$root/ns:Titre"/>
			<xsl:with-param name="prenom" select="$root/ns:Prenom"/>
			<xsl:with-param name="nom" select="$root/ns:Nom"/>
		</xsl:call-template>
		<xsl:call-template name="EDIFACT-COM">
			<xsl:with-param name="tel" select="$root/ns:Tel"/>
		</xsl:call-template>
	</xsl:template>
	
	<xsl:template name="SEGMENT-GROUP-3">
		<xsl:variable name="root" select="ns:SeqInO41/ns:Conc1/ns:Context/ns:Dev"/>
		<xsl:call-template name="EDIFACT-CUX">
			<xsl:with-param name="cdDevIso" select="$root/ns:CdDevIso"/>
			<xsl:with-param name="txChgeIml" select="$root/../ns:ContextRapAnn41/ns:TxChge"/>
		</xsl:call-template>
		<xsl:call-template name="EDIFACT-UNS">
			<xsl:with-param name="type" select="'D'"/>
		</xsl:call-template>
	</xsl:template>
	
	<xsl:template name="SEGMENT-GROUP-4">
		<xsl:call-template name="ETAT-PATRIMOINE"/>
		<xsl:call-template name="RESULTATS-OPERATIONS"/>
		<xsl:call-template name="CHANGEMENTS-ACTIF-NET"/>
		<xsl:call-template name="MOUVEMENT-PORTEFEUILLE"/>
	</xsl:template>
	
	<xsl:template name="ETAT-PATRIMOINE">
		<xsl:call-template name="ACTIF"/>
		<xsl:call-template name="PASSIF"/>
		<xsl:call-template name="ACTIF-NET-FIN-EXERCICE"/>
	</xsl:template>
	
	<xsl:template name="ACTIF">
		<xsl:for-each select="ns:SeqInO41/ns:Conc1/ns:Patrim/*">
			<xsl:if test="matches(local-name(), 'L1\*?')">
				<xsl:call-template name="LIGNE-REPORTING">
					<xsl:with-param name="coded-account" select="concat('1-',fnbcl:convert-numLigne(substring(local-name(), 2)))"/>
					<xsl:with-param name="montant" select="./ns:Mt"/>
				</xsl:call-template>
			</xsl:if>
			
			<!-- <xsl:if test="matches(local-name(), 'MtIml1\*?')">
				<xsl:call-template name="LIGNE-REPORTING">
					<xsl:with-param name="coded-account" select="concat('1-',fnbcl:convert-numLigne(substring(local-name(), 6)))"/>
					<xsl:with-param name="montant" select="."/>
				</xsl:call-template>
			</xsl:if> -->
		</xsl:for-each>
		<xsl:variable name="champ" select="ns:SeqInO41/ns:Conc1/ns:Patrim/ns:PatrimRapAnn41/ns:MtIml1211" />
		<xsl:call-template name="LIGNE-REPORTING">
			<xsl:with-param name="coded-account" select="concat('1-',fnbcl:convert-numLigne(substring(local-name($champ), 6)))"/>
			<xsl:with-param name="montant" select="$champ"/>
		</xsl:call-template>
		<xsl:variable name="champ" select="ns:SeqInO41/ns:Conc1/ns:Patrim/ns:PatrimRapAnn41/ns:MtIml1212" />
		<xsl:call-template name="LIGNE-REPORTING">
			<xsl:with-param name="coded-account" select="concat('1-',fnbcl:convert-numLigne(substring(local-name($champ), 6)))"/>
			<xsl:with-param name="montant" select="$champ"/>
		</xsl:call-template>
		<xsl:variable name="champ" select="ns:SeqInO41/ns:Conc1/ns:Patrim/ns:PatrimRapAnn41/ns:MtIml1220" />
		<xsl:call-template name="LIGNE-REPORTING">
			<xsl:with-param name="coded-account" select="concat('1-',fnbcl:convert-numLigne(substring(local-name($champ), 6)))"/>
			<xsl:with-param name="montant" select="$champ"/>
		</xsl:call-template>
		<xsl:variable name="champ" select="ns:SeqInO41/ns:Conc1/ns:Patrim/ns:PatrimRapAnn41/ns:MtIml1230" />
		<xsl:call-template name="LIGNE-REPORTING">
			<xsl:with-param name="coded-account" select="concat('1-',fnbcl:convert-numLigne(substring(local-name($champ), 6)))"/>
			<xsl:with-param name="montant" select="$champ"/>
		</xsl:call-template>
		<xsl:variable name="champ" select="ns:SeqInO41/ns:Conc1/ns:Patrim/ns:PatrimRapAnn41/ns:MtIml1311" />
		<xsl:call-template name="LIGNE-REPORTING">
			<xsl:with-param name="coded-account" select="concat('1-',fnbcl:convert-numLigne(substring(local-name($champ), 6)))"/>
			<xsl:with-param name="montant" select="$champ"/>
		</xsl:call-template>
		<xsl:variable name="champ" select="ns:SeqInO41/ns:Conc1/ns:Patrim/ns:PatrimRapAnn41/ns:MtIml1312" />
		<xsl:call-template name="LIGNE-REPORTING">
			<xsl:with-param name="coded-account" select="concat('1-',fnbcl:convert-numLigne(substring(local-name($champ), 6)))"/>
			<xsl:with-param name="montant" select="$champ"/>
		</xsl:call-template>
		<xsl:variable name="champ" select="ns:SeqInO41/ns:Conc1/ns:Patrim/ns:PatrimRapAnn41/ns:MtIml1420" />
		<xsl:call-template name="LIGNE-REPORTING">
			<xsl:with-param name="coded-account" select="concat('1-',fnbcl:convert-numLigne(substring(local-name($champ), 6)))"/>
			<xsl:with-param name="montant" select="$champ"/>
		</xsl:call-template>
		<xsl:variable name="champ" select="ns:SeqInO41/ns:Conc1/ns:Patrim/ns:PatrimRapAnn41/ns:MtIml1510" />
		<xsl:call-template name="LIGNE-REPORTING">
			<xsl:with-param name="coded-account" select="concat('1-',fnbcl:convert-numLigne(substring(local-name($champ), 6)))"/>
			<xsl:with-param name="montant" select="$champ"/>
		</xsl:call-template>
		<xsl:variable name="champ" select="ns:SeqInO41/ns:Conc1/ns:Patrim/ns:PatrimRapAnn41/ns:MtIml1520" />
		<xsl:call-template name="LIGNE-REPORTING">
			<xsl:with-param name="coded-account" select="concat('1-',fnbcl:convert-numLigne(substring(local-name($champ), 6)))"/>
			<xsl:with-param name="montant" select="$champ"/>
		</xsl:call-template>
	</xsl:template>
	
	<xsl:template name="PASSIF">
	<xsl:variable name="champ" select="ns:SeqInO41/ns:Conc1/ns:Patrim/ns:PatrimRapAnn41/ns:MtIml2100" />
		<xsl:call-template name="LIGNE-REPORTING">
			<xsl:with-param name="coded-account" select="concat('1-',fnbcl:convert-numLigne(substring(local-name($champ), 6)))"/>
			<xsl:with-param name="montant" select="$champ"/>
		</xsl:call-template>
		<xsl:variable name="champ" select="ns:SeqInO41/ns:Conc1/ns:Patrim/ns:PatrimRapAnn41/ns:MtIml2200" />
		<xsl:call-template name="LIGNE-REPORTING">
			<xsl:with-param name="coded-account" select="concat('1-',fnbcl:convert-numLigne(substring(local-name($champ), 6)))"/>
			<xsl:with-param name="montant" select="$champ"/>
		</xsl:call-template>
	</xsl:template>
	
	<xsl:template name="ACTIF-NET-FIN-EXERCICE">
			<xsl:variable name="champ" select="ns:SeqInO41/ns:Conc1/ns:Patrim/ns:Mt3000" />
			<xsl:call-template name="LIGNE-REPORTING">
				<xsl:with-param name="coded-account" select="concat('1-',fnbcl:convert-numLigne(substring(local-name($champ), 3)))"/>
				<xsl:with-param name="montant" select="$champ"/>
			</xsl:call-template>
	</xsl:template>
	
	<xsl:template name="RESULTATS-OPERATIONS">
		<xsl:call-template name="REVENU"/>
		<xsl:call-template name="CHARGE"/>
		<xsl:call-template name="RESULTAT-NET-INVESTISSEMENT"/>
	</xsl:template>
	
	<xsl:template name="REVENU">
	<xsl:for-each select="ns:SeqInO41/ns:Conc1/ns:Ope/ns:OpeRapAnn41/*">
		<xsl:if test="matches(local-name(), 'MtIml4\*?')">
			<xsl:call-template name="LIGNE-REPORTING">
				<xsl:with-param name="coded-account" select="concat('1-',fnbcl:convert-numLigne(substring(local-name(), 6)))"/>
				<xsl:with-param name="montant" select="."/>
			</xsl:call-template>
		</xsl:if>
	</xsl:for-each>
	</xsl:template>
	
	<xsl:template name="CHARGE">
	<xsl:for-each select="ns:SeqInO41/ns:Conc1/ns:Ope/ns:OpeRapAnn41/*">
		<xsl:if test="matches(local-name(), 'MtIml5\*?')">
			<xsl:call-template name="LIGNE-REPORTING">
				<xsl:with-param name="coded-account" select="concat('1-',fnbcl:convert-numLigne(substring(local-name(), 6)))"/>
				<xsl:with-param name="montant" select="."/>
			</xsl:call-template>
		</xsl:if>
	</xsl:for-each>
	</xsl:template>
	
	<xsl:template name="RESULTAT-NET-INVESTISSEMENT">
		<xsl:variable name="champ" select="ns:SeqInO41/ns:Conc1/ns:Ope/ns:OpeRapAnn41/ns:MtIml7100" />
		<xsl:call-template name="LIGNE-REPORTING">
			<xsl:with-param name="coded-account" select="concat('1-',fnbcl:convert-numLigne(substring(local-name($champ), 6)))"/>
			<xsl:with-param name="montant" select="$champ"/>
		</xsl:call-template>
		<xsl:variable name="champ" select="ns:SeqInO41/ns:Conc1/ns:Ope/ns:OpeRapAnn41/ns:MtIml7200" />
		<xsl:call-template name="LIGNE-REPORTING">
			<xsl:with-param name="coded-account" select="concat('1-',fnbcl:convert-numLigne(substring(local-name($champ), 6)))"/>
			<xsl:with-param name="montant" select="$champ"/>
		</xsl:call-template>
	</xsl:template>
	
	<xsl:template name="CHANGEMENTS-ACTIF-NET">
		<xsl:call-template name="ACTIF-NET-DEBUT-EXERCICE"/>
	</xsl:template>
	
	<xsl:template name="ACTIF-NET-DEBUT-EXERCICE">
		<xsl:variable name="champ" select="ns:SeqInO41/ns:Conc1/ns:Actif/ns:ActifRapAnn41/ns:MtIml3001" />
		<xsl:call-template name="LIGNE-REPORTING">
			<xsl:with-param name="coded-account" select="concat('1-',fnbcl:convert-numLigne(substring(local-name($champ), 6)))"/>
			<xsl:with-param name="montant" select="$champ"/>
		</xsl:call-template>
		<!-- <xsl:call-template name="RESULTAT-OPERATIONS"/> -->
		<xsl:variable name="champ" select="ns:SeqInO41/ns:Conc1/ns:Actif/ns:ActifRapAnn41/ns:MtIml8100" />
		<xsl:call-template name="LIGNE-REPORTING">
			<xsl:with-param name="coded-account" select="concat('1-',fnbcl:convert-numLigne(substring(local-name($champ), 6)))"/>
			<xsl:with-param name="montant" select="$champ"/>
		</xsl:call-template>
		<xsl:variable name="champ" select="ns:SeqInO41/ns:Conc1/ns:Actif/ns:ActifRapAnn41/ns:MtIml8200" />
		<xsl:call-template name="LIGNE-REPORTING">
			<xsl:with-param name="coded-account" select="concat('1-',fnbcl:convert-numLigne(substring(local-name($champ), 6)))"/>
			<xsl:with-param name="montant" select="$champ"/>
		</xsl:call-template>
		<xsl:variable name="champ" select="ns:SeqInO41/ns:Conc1/ns:Actif/ns:ActifRapAnn41/ns:MtIml9000" />
		<xsl:call-template name="LIGNE-REPORTING">
			<xsl:with-param name="coded-account" select="concat('1-',fnbcl:convert-numLigne(substring(local-name($champ), 6)))"/>
			<xsl:with-param name="montant" select="$champ"/>
		</xsl:call-template>
		<xsl:variable name="champ" select="ns:SeqInO41/ns:Conc1/ns:Actif/ns:ActifRapAnn41/ns:MtIml9100" />
		<xsl:call-template name="LIGNE-REPORTING">
			<xsl:with-param name="coded-account" select="concat('1-',fnbcl:convert-numLigne(substring(local-name($champ), 6)))"/>
			<xsl:with-param name="montant" select="$champ"/>
		</xsl:call-template>
	</xsl:template>
	
	<xsl:template name="MOUVEMENT-PORTEFEUILLE">
		<xsl:call-template name="TOTAL-ACHATS-VENTES-VALEURS-MOBILIERES-AUTRES"/>
	</xsl:template>
	
	<xsl:template name="TOTAL-ACHATS-VENTES-VALEURS-MOBILIERES-AUTRES">
		<xsl:for-each select="ns:SeqInO41/ns:Conc1/ns:Mvt/ns:MvtRapAnn41/*">
		<xsl:if test="matches(local-name(), 'MtIml9\*?')">
			<xsl:call-template name="LIGNE-REPORTING">
				<xsl:with-param name="coded-account" select="concat('1-',fnbcl:convert-numLigne(substring(local-name(), 6)))"/>
				<xsl:with-param name="montant" select="."/>
			</xsl:call-template>
		</xsl:if>
	</xsl:for-each>
	</xsl:template>
	
	
	<xsl:template name="VENTILATION-PORTEFEUILLE-TITRES-AVOIRS">
		<xsl:variable name="root" select="ns:SeqInO41/ns:Conc1/ns:Patrim" />
		<xsl:for-each select="ns:SeqInO41/ns:Conc1/ns:Patrim/ns:L1112/ns:S1112[ns:Pays/ns:CdPaysIso2 != '']">
			<xsl:call-template name="LIGNE-REPORTING">
				<xsl:with-param name="coded-account" select="concat('2-11111-', ns:Pays/ns:CdPaysIso2)"/>
				<xsl:with-param name="montant" select="ns:PaysEmisRap411112/ns:MtIml1112"/>
			</xsl:call-template>
		</xsl:for-each>
		<xsl:for-each select="ns:SeqInO41/ns:Conc1/ns:Patrim/ns:L1113/ns:S1113[ns:Pays/ns:CdPaysIso2 != '']">
			<xsl:call-template name="LIGNE-REPORTING">
				<xsl:with-param name="coded-account" select="concat('2-11112-', ns:Pays/ns:CdPaysIso2)"/>
				<xsl:with-param name="montant" select="ns:PaysEmisRap411113/ns:MtIml1113"/>
			</xsl:call-template>
		</xsl:for-each>
		<xsl:for-each select="ns:SeqInO41/ns:Conc1/ns:Patrim/ns:L1114/ns:S1114[ns:Pays/ns:CdPaysIso2 != '']">
			<xsl:call-template name="LIGNE-REPORTING">
				<xsl:with-param name="coded-account" select="concat('2-11120-', ns:Pays/ns:CdPaysIso2)"/>
				<xsl:with-param name="montant" select="ns:PaysEmisRap411114/ns:MtIml1114"/>
			</xsl:call-template>
		</xsl:for-each>
		<xsl:for-each select="ns:SeqInO41/ns:Conc1/ns:Patrim/ns:L1115/ns:S1115[ns:Pays/ns:CdPaysIso2 != '']">
			<xsl:call-template name="LIGNE-REPORTING">
				<xsl:with-param name="coded-account" select="concat('2-11130-', ns:Pays/ns:CdPaysIso2)"/>
				<xsl:with-param name="montant" select="ns:PaysEmisRap411115/ns:MtIml1115"/>
			</xsl:call-template>
		</xsl:for-each>
		<xsl:for-each select="ns:SeqInO41/ns:Conc1/ns:Patrim/ns:L1121/ns:S1121[ns:Pays/ns:CdPaysIso2 != '']">
			<xsl:call-template name="LIGNE-REPORTING">
				<xsl:with-param name="coded-account" select="concat('2-11210-', ns:Pays/ns:CdPaysIso2)"/>
				<xsl:with-param name="montant" select="ns:PaysEmisRap411121/ns:MtIml1121"/>
			</xsl:call-template>
		</xsl:for-each>
		<xsl:for-each select="ns:SeqInO41/ns:Conc1/ns:Patrim/ns:L1122/ns:S1122[ns:Pays/ns:CdPaysIso2 != '']">
			<xsl:call-template name="LIGNE-REPORTING">
				<xsl:with-param name="coded-account" select="concat('2-11220-', ns:Pays/ns:CdPaysIso2)"/>
				<xsl:with-param name="montant" select="ns:PaysEmisRap411122/ns:MtIml1122"/>
			</xsl:call-template>
		</xsl:for-each>
		<xsl:for-each select="ns:SeqInO41/ns:Conc1/ns:Patrim/ns:L1130/ns:S1130[ns:Pays/ns:CdPaysIso2 != '']">
			<xsl:call-template name="LIGNE-REPORTING">
				<xsl:with-param name="coded-account" select="concat('2-11300-', ns:Pays/ns:CdPaysIso2)"/>
				<xsl:with-param name="montant" select="ns:PaysEmisRap411130/ns:MtIml1130"/>
			</xsl:call-template>
		</xsl:for-each>
		<xsl:for-each select="ns:SeqInO41/ns:Conc1/ns:Patrim/ns:L1140/ns:S1140[ns:Pays/ns:CdPaysIso2 != '']">
			<xsl:call-template name="LIGNE-REPORTING">
				<xsl:with-param name="coded-account" select="concat('2-11400-', ns:Pays/ns:CdPaysIso2)"/>
				<xsl:with-param name="montant" select="ns:PaysEmisRap411140/ns:MtIml1140"/>
			</xsl:call-template>
		</xsl:for-each>
		<xsl:for-each select="ns:SeqInO41/ns:Conc1/ns:Patrim/ns:L1320/ns:S1320[ns:Pays/ns:CdPaysIso2 != '']">
			<xsl:call-template name="LIGNE-REPORTING">
				<xsl:with-param name="coded-account" select="concat('2-13200-', ns:Pays/ns:CdPaysIso2)"/>
				<xsl:with-param name="montant" select="ns:PaysEmisRap411320/ns:MtIml1320"/>
			</xsl:call-template>
		</xsl:for-each>
		<xsl:for-each select="ns:SeqInO41/ns:Conc1/ns:Patrim/ns:L1410/ns:S1410[ns:Pays/ns:CdPaysIso2 != '']">
			<xsl:call-template name="LIGNE-REPORTING">
				<xsl:with-param name="coded-account" select="concat('2-14100-', ns:Pays/ns:CdPaysIso2)"/>
				<xsl:with-param name="montant" select="ns:PaysEmisRap411410/ns:MtIml1410"/>
			</xsl:call-template>
		</xsl:for-each>
		<xsl:for-each select="ns:SeqInO41/ns:Conc1/ns:Cmce/ns:Scmce[ns:Pays/ns:CdPaysIso2 != '']">
			<xsl:call-template name="LIGNE-REPORTING">
				<xsl:with-param name="coded-account" select="concat('3-', ns:Pays/ns:CdPaysIso2)"/>
				<xsl:with-param name="montant" select="ns:CollPaysCmceRapO41B/ns:EstimPourcPart"/>
			</xsl:call-template>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template name="SEGMENT-GROUP-5">
		<xsl:param name="nbSegments"/>

		<xsl:call-template name="EDIFACT-FTX" />
		<xsl:variable name="root" select="ns:other/ns:EltTech"/>
		<xsl:call-template name="EDIFACT-AUT">
			<xsl:with-param name="cdAuthent" select="$root/ns:CdAuthent"/>
		</xsl:call-template>
		<xsl:variable name="root" select="/ns:MsgInO41/ns:other/ns:EltTech"/>
		<xsl:call-template name="EDIFACT-DTM">
			<xsl:with-param name="typeDate" select="'218'"/>
			<xsl:with-param name="date" select="$root/ns:DtValidat" as="xs:dateTime"/>
			<xsl:with-param name="formatDateCd" select="$formatDateCd" />
		</xsl:call-template>
		<xsl:variable name="root" select="ns:other/ns:EltTech"/>
		<xsl:variable name="idAc" select="$root/ns:CdIdentAcCssf"/>
		<xsl:variable name="idAc7digit" select="ext:convertIdAcTo7Digit($idAc)"/>
    <!-- 			$compteurSegments+1 car ajout du segment FTX -->
 		<xsl:call-template name="EDIFACT-UNT">
			<xsl:with-param name="nbSegments" select="$compteurCPT*3+$compteurSegments+1"/>
			<xsl:with-param name="cdIdentAc" select="$idAc7digit" />
			<xsl:with-param name="dtCre" select="$root/ns:DtCre" as="xs:dateTime" />
			<xsl:with-param name="numMess" select="$root/ns:NumMess" />
			<xsl:with-param name="formatDateCd" select="$formatDateCd" />
		</xsl:call-template>
		
		<xsl:variable name="root" select="ns:other/ns:EltTech"/>
		<xsl:variable name="idAc" select="$root/ns:CdIdentAcCssf"/>
		<xsl:variable name="idAc7digit" select="ext:convertIdAcTo7Digit($idAc)"/>			
		<xsl:call-template name="EDIFACT-UNZ">
			<xsl:with-param name="cdIdentAc" select="$idAc7digit" />
			<xsl:with-param name="dtCre" select="$root/ns:DtCre" as="xs:dateTime" />
			<xsl:with-param name="formatDateCd" select="$formatDateCd" />
		</xsl:call-template>

	</xsl:template>
	
	<xsl:template name="LIGNE-REPORTING">
		<xsl:param name="coded-account"/>
		<xsl:param name="montant" as="xs:decimal"/>
		<saxon:assign name="compteurCPT" select="$compteurCPT+1"/>
		<xsl:call-template name="EDIFACT-CPT">
			<xsl:with-param name="coded-account" select="$coded-account"/>
		</xsl:call-template>
		<xsl:call-template name="EDIFACT-VAL">
			<xsl:with-param name="type" select="'AMT'"/>
			<xsl:with-param name="montant" select="$montant" as="xs:decimal"/>
		</xsl:call-template>
		<xsl:call-template name="EDIFACT-QTY">
			<xsl:with-param name="compteur" select="1"/>
		</xsl:call-template>
	</xsl:template>
	
	<xsl:template name="SUMMARY-SECTION">
		<xsl:param name="compteur"/>
		<xsl:call-template name="EDIFACT-UNS">
			<xsl:with-param name="type" select="'S'"/>
		</xsl:call-template>
		<xsl:call-template name="EDIFACT-QTY">
			<xsl:with-param name="compteur" select="$compteur"/>
		</xsl:call-template>
		<xsl:call-template name="EDIFACT-VAL">
			<xsl:with-param name="type" select="'AMT'"/>
			<xsl:with-param name="montant" select="0" as="xs:decimal"/>
		</xsl:call-template>
	</xsl:template>
	
	
	
	
</xsl:stylesheet>
